@@ -702,167 +702,6 @@ def test_outliers():
     assert move_df.len() == 1
 
 
-def test_clean_duplicates():
-    move_df, cols = _prepare_df_default(list_data_1)
-
-    duplicates_all = filters.clean_duplicates(move_df)
-    expected = DataFrame(
-        [
-            [
-                39.984092712402344,
-                116.31923675537101,
-                Timestamp('2008-10-23 05:53:05'),
-                1,
-            ],
-            [
-                39.984199952392578,
-                116.31932067871094,
-                Timestamp('2008-10-23 05:53:06'),
-                1,
-            ],
-            [
-                39.984222412109375,
-                116.31940460205078,
-                Timestamp('2008-10-23 05:53:11'),
-                2,
-            ],
-        ],
-        columns=cols,
-        index=[0, 1, 2],
-    )
-    assert_frame_equal(duplicates_all, expected)
-    assert move_df.len() == 4
-
-    duplicates_subset = filters.clean_duplicates(move_df, subset=TRAJ_ID)
-    expected = DataFrame(
-        [
-            [
-                39.984092712402344,
-                116.31923675537101,
-                Timestamp('2008-10-23 05:53:05'),
-                1,
-            ],
-            [
-                39.984222412109375,
-                116.31940460205078,
-                Timestamp('2008-10-23 05:53:11'),
-                2,
-            ],
-        ],
-        columns=cols,
-        index=[0, 2],
-    )
-    assert_frame_equal(duplicates_subset, expected)
-    assert move_df.len() == 4
-
-    duplicates_last = filters.clean_duplicates(
-        move_df, subset=TRAJ_ID, keep='last'
-    )
-    expected = DataFrame(
-        [
-            [
-                39.984199952392578,
-                116.31932067871094,
-                Timestamp('2008-10-23 05:53:06'),
-                1,
-            ],
-            [
-                39.984222412109375,
-                116.31940460205078,
-                Timestamp('2008-10-23 05:53:11'),
-                2,
-            ],
-        ],
-        columns=cols,
-        index=[1, 3],
-    )
-    assert_frame_equal(duplicates_last, expected)
-    assert move_df.len() == 4
-
-    filters.clean_duplicates(move_df, subset=TRAJ_ID, inplace=True)
-    expected = DataFrame(
-        [
-            [
-                39.984092712402344,
-                116.31923675537101,
-                Timestamp('2008-10-23 05:53:05'),
-                1,
-            ],
-            [
-                39.984222412109375,
-                116.31940460205078,
-                Timestamp('2008-10-23 05:53:11'),
-                2,
-            ],
-        ],
-        columns=cols,
-        index=[0, 2],
-    )
-    assert_frame_equal(move_df, expected)
-    assert move_df.len() == 2
-
-
-def test_clean_nan_values():
-    move_df, cols = _prepare_df_default(list_data_1)
-    move_df.loc[3, TRAJ_ID] = nan
-
-    drop_nan = filters.clean_nan_values(move_df)
-    expected = DataFrame(
-        [
-            [
-                39.984092712402344,
-                116.31923675537101,
-                Timestamp('2008-10-23 05:53:05'),
-                1.0,
-            ],
-            [
-                39.984199952392578,
-                116.31932067871094,
-                Timestamp('2008-10-23 05:53:06'),
-                1.0,
-            ],
-            [
-                39.984222412109375,
-                116.31940460205078,
-                Timestamp('2008-10-23 05:53:11'),
-                2.0,
-            ],
-        ],
-        columns=cols,
-        index=[0, 1, 2],
-    )
-    assert_frame_equal(drop_nan, expected)
-    assert move_df.len() == 4
-
-    filters.clean_nan_values(move_df, inplace=True)
-    expected = DataFrame(
-        [
-            [
-                39.984092712402344,
-                116.31923675537101,
-                Timestamp('2008-10-23 05:53:05'),
-                1.0,
-            ],
-            [
-                39.984199952392578,
-                116.31932067871094,
-                Timestamp('2008-10-23 05:53:06'),
-                1.0,
-            ],
-            [
-                39.984222412109375,
-                116.31940460205078,
-                Timestamp('2008-10-23 05:53:11'),
-                2.0,
-            ],
-        ],
-        columns=cols,
-        index=[0, 1, 2],
-    )
-    assert_frame_equal(drop_nan, expected)
-    assert move_df.len() == 3
-
-
 def test_clean_gps_jumps_by_distance():
     move_df, cols = _prepare_df_with_distances()
 
