@@ -173,3 +173,6 @@ MAX = 'max'
 SUM = 'sum'
 
 POINT = 'Point'
+
+N_CLUSTER = 'n_cluster'
+EARTH_RADIUS = 6371
